@@ -14,12 +14,12 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import print_function
+
 import os
 import sys
 import calculate.contrib
 from suds import MethodNotFound
-from calculate.core.server.cert_cmd import getHwAddr, getIpLocal
+from ..server.cert_cmd import getHwAddr, getIpLocal
 _ = lambda x: x
 from calculate.lib.cl_lang import setLocalTranslate
 
@@ -70,13 +70,11 @@ def create_obj(client, method_name):
     ns_type = 1
     param = 1
     pref = ""
-
     sd = client.sd[sd_item]
 
     # get parameter type
     operation = sd.ports[num_port][operation_from_port]
-
-    info = operation.methods.get(method_name)
+    info = operation.method(method_name)
     if not info:
         raise MethodNotFound(method_name)
     type_op = info.binding.input.param_defs(info)[param][inf_param]
@@ -115,7 +113,7 @@ def listToArrayArray(client, _list, _type='string'):
     return array_array
 
 
-class switch(object):
+class switch():
     def __init__(self, value):
         self.value = value
         self.fall = False
