@@ -367,8 +367,8 @@ class Basic(Service):
             OpenSSL.SSL.FILETYPE_PEM, cert)
         subject = cert_obj.get_subject().get_components()
         for subj in subject:
-            if subj[0] == 'CN':
-                return subj[1]
+            if subj[0] == b'CN':
+                return subj[1].decode("UTF-8")
         return b'No server host name provided'
 
     @rpc(_returns=String)
