@@ -45,9 +45,7 @@ _('No module named %s')
 def main(*args, **keywords):
     _args = list(unpack_single_opts(sys.argv[1:]))
     caller = os.path.basename(sys.argv[0]) 
-    #TODO uncomment
-    # if not (caller == 'cl-core' or caller == 'cl-core_py3'):
-    if False:
+    if not (caller == 'cl-core' or caller == 'cl-core_py3' or caller == "run_debug_core.py"):
         parser = cert_cmd.parse(full=False)
         args, unknown_args = parser.parse_known_args(_args)
         args.method = '_temp_'
